@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2021 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,15 +13,13 @@
 #
 # END HEADER
 
-from __future__ import division, print_function, absolute_import
-
 from hypothesis.extra.pandas.impl import (
-    series,
-    data_frames,
     column,
     columns,
+    data_frames,
     indexes,
     range_indexes,
+    series,
 )
 
 __all__ = ["indexes", "range_indexes", "series", "column", "columns", "data_frames"]
