@@ -44,7 +44,7 @@ def sign(x):
         return math.copysign(1.0, x)
     except TypeError:
         raise TypeError(
-            "Expected float but got %r of type %s" % (x, type(x).__name__)
+            f"Expected float but got {x!r} of type {type(x).__name__}"
         ) from None
 
 
